==> aws-cdk.aws-codepipeline-actions-1.100.0.tar.gz: package/lib/servicecatalog/deploy-action-beta1.d.ts <==
import * as codepipeline from '@aws-cdk/aws-codepipeline';
import { Action } from '../action';
import { Construct } from '@aws-cdk/core';
/**
 * Construction properties of the {@link ServiceCatalogDeployActionBeta1 ServiceCatalog deploy CodePipeline Action}.
 *
 * @stability stable
 */
export interface ServiceCatalogDeployActionBeta1Props extends codepipeline.CommonAwsActionProps {
    /**
     * The path to the cloudformation artifact.
     *
     * @stability stable
     */
    readonly templatePath: codepipeline.ArtifactPath;
    /**
     * The name of the version of the Service Catalog product to be deployed.
     *
     * @stability stable
     */
    readonly productVersionName: string;
    /**
     * The optional description of this version of the Service Catalog product.
     *
     * @default ''
     * @stability stable
     */
    readonly productVersionDescription?: string;
    /**
     * The identifier of the product in the Service Catalog.
     *
     * This product must already exist.
     *
     * @stability stable
     */
    readonly productId: string;
}
/**
 * CodePipeline action to connect to an existing ServiceCatalog product.
 *
 * @stability stable
 */
export declare class ServiceCatalogDeployActionBeta1 extends Action {
    private readonly templatePath;
    private readonly productVersionName;
    private readonly productVersionDescription?;
    private readonly productId;
    private readonly productType;
    /**
     * @stability stable
     */
    constructor(props: ServiceCatalogDeployActionBeta1Props);
    /**
     * This is a renamed version of the {@link IAction.bind} method.
     *
     * @stability stable
     */
    protected bound(_scope: Construct, _stage: codepipeline.IStage, options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
}

==> aws-cdk.aws-codepipeline-actions-1.114.0.tar.gz: package/lib/servicecatalog/deploy-action-beta1.d.ts <==
import * as codepipeline from '@aws-cdk/aws-codepipeline';
import { Action } from '../action';
import { Construct } from '@aws-cdk/core';
/**
 * Construction properties of the {@link ServiceCatalogDeployActionBeta1 ServiceCatalog deploy CodePipeline Action}.
 *
 * @stability stable
 */
export interface ServiceCatalogDeployActionBeta1Props extends codepipeline.CommonAwsActionProps {
    /**
     * The path to the cloudformation artifact.
     *
     * @stability stable
     */
    readonly templatePath: codepipeline.ArtifactPath;
    /**
     * The name of the version of the Service Catalog product to be deployed.
     *
     * @stability stable
     */
    readonly productVersionName: string;
    /**
     * The optional description of this version of the Service Catalog product.
     *
     * @default ''
     * @stability stable
     */
    readonly productVersionDescription?: string;
    /**
     * The identifier of the product in the Service Catalog.
     *
     * This product must already exist.
     *
     * @stability stable
     */
    readonly productId: string;
}
/**
 * CodePipeline action to connect to an existing ServiceCatalog product. <<<<<<< HEAD:packages/@aws-cdk/aws-codepipeline-actions/lib/servicecatalog/deploy-action.ts.
 *
 * **Note**: this class is still experimental, and may have breaking changes in the future!
 *
 * =======
 * >>>>>>> master:packages/@aws-cdk/aws-codepipeline-actions/lib/servicecatalog/deploy-action-beta1.ts
 *
 * @stability stable
 */
export declare class ServiceCatalogDeployActionBeta1 extends Action {
    private readonly templatePath;
    private readonly productVersionName;
    private readonly productVersionDescription?;
    private readonly productId;
    private readonly productType;
    /**
     * @stability stable
     */
    constructor(props: ServiceCatalogDeployActionBeta1Props);
    /**
     * This is a renamed version of the {@link IAction.bind} method.
     *
     * @stability stable
     */
    protected bound(_scope: Construct, _stage: codepipeline.IStage, options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
}
